measure_it
==========

`measure_it <http://github.com/wearpants/measure_it>`__ provides timing and counting for iterators (and other code segments). It can be used to:

* monitor runtime behavior in production systems
* conduct performance benchmarks
* easily generate plots/graphs and statistics

Get it from the cheeseshop today:

  `pip install measure_it`

:author: Pete Fein <pete@wearpants.org>
:license: BSD
:versions: Python 2.7 & 3
:source: https://github.com/wearpants/measure_it
:homepage: https://measure_it.readthedocs.org/en/latest/
:video: https://www.youtube.com/watch?v=A_C4Z4RDDgI

